# glob-object [![NPM version](https://img.shields.io/npm/v/glob-object.svg)](https://www.npmjs.com/package/glob-object) [![Build Status](https://img.shields.io/travis/jonschlinkert/glob-object.svg)](https://travis-ci.org/jonschlinkert/glob-object)

> Filter an object using glob patterns and dot notation.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install glob-object --save
```

## Usage

```js
var globObject = require('glob-object');

globObject('a.*.f', {a: {b: {c: 'd'}, e: {f: 'g'}}});
//=> { a: { e: { f: 'g' } } }
```

## Examples

Given the following object:

```js
var obj = {
  a: {
    b: {
      c: 'd',
      e: 'f',
      g: 'h',
      i: {j: 'k'},
      l: {g: 'k'}
    },
    i: 'j'
  }
};
```

## match properties using wildcards

```js
globObject('*', obj);
//=> obj (matches all keys)
```

## match properties using braces

```js
globObject('a.*.{c,e}', obj);
//=> {a: {b: {c: 'd', e: 'f'}}}
```

## match a nested property using a wildcard

A single star will match one level of the object:

```js
globObject('a.*.g', obj);
//=> {a: {b: {g: 'h'}}}
```

## match deep properties using globstars

A double star will match to any depth (note that the single star in the previous example did not match `a.b.l.g`):

```js
globObject('a.**.g', obj);
//=> {a: {b: {g: 'h', l: {g: 'k'}}}}
```

## Related projects

* [expand-object](https://www.npmjs.com/package/expand-object): Expand a string into a JavaScript object using a simple notation. Use the CLI or… [more](https://www.npmjs.com/package/expand-object) | [homepage](https://github.com/jonschlinkert/expand-object)
* [get-value](https://www.npmjs.com/package/get-value): Use property paths (`  a.b.c`) to get a nested value from an object. | [homepage](https://github.com/jonschlinkert/get-value)
* [has-value](https://www.npmjs.com/package/has-value): Returns true if a value exists, false if empty. Works with deeply nested values using… [more](https://www.npmjs.com/package/has-value) | [homepage](https://github.com/jonschlinkert/has-value)
* [set-value](https://www.npmjs.com/package/set-value): Create nested values and any intermediaries using dot notation (`'a.b.c'`) paths. | [homepage](https://github.com/jonschlinkert/set-value)
* [stringify-keys](https://www.npmjs.com/package/stringify-keys): Build an array of key paths from an object. | [homepage](https://github.com/doowb/stringify-keys)

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/glob-object/issues/new).

## Building docs

Generate readme and API documentation with [verb](https://github.com/verbose/verb):

```sh
$ npm install verb && npm run docs
```

Or, if [verb](https://github.com/verbose/verb) is installed globally:

```sh
$ verb
```

## Running tests

Install dev dependencies:

```sh
$ npm install -d && npm test
```

## Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License

Copyright © 2016 [Jon Schlinkert](https://github.com/jonschlinkert)
Released under the [MIT license](https://github.com/jonschlinkert/glob-object/blob/master/LICENSE).

***

_This file was generated by [verb](https://github.com/verbose/verb), v0.9.0, on March 19, 2016._